rulebase.const package
======================

Submodules
----------

.. toctree::

   rulebase.const.chinese_chars
   rulebase.const.delimiters
   rulebase.const.digits
   rulebase.const.english_chars
   rulebase.const.utils

Module contents
---------------

.. automodule:: rulebase.const
    :members:
    :undoc-members:
    :show-inheritance:
